<?php
/*
Plugin Name: WP Update Message
Plugin URI: http://www.jenst.se/2009/06/14/wp-update-message/
Description: Add an update message to your pages or posts to let your readers know what has been updated.
Version: 1.2
Author: Jens T&ouml;rnell
Author URI: http://www.jenst.se
*/

add_action('admin_menu', 'my_post_options_box');
add_action('save_post', 'update_message_save');
add_filter('the_content', 'update_message_content');
add_action('wp_head', 'update_message_style_theme');

function update_message_style_theme()
{
	$settings = get_option('wpudma');
	$style_theme = $settings["style_theme"];
	
	if($style_theme == '')
	{
		$style_theme = 'green';
	}
	
	if($style_theme != 'none')
	{
		$style_url = plugins_url("wp-update-message/style-themes/$style_theme.css");
		
		$output .= "\n\n<!-- WP Updated Message - START -->\n";
		$output .= '<link rel="stylesheet" href="'.$style_url.'" type="text/css" media="screen" />' . "\n";
		$output .= "<!-- WP Updated Message - END -->\n";
		
		echo $output;
	}
}


function my_post_options_box() {
	add_options_page('Update message options', 'Update message', 8, __FILE__, 'wpudma_options');
	add_meta_box('post_info', 'Update message', 'custom_post_info', 'post', 'normal', 'low');
}

function custom_post_info() {
	global $post;
	
	echo '<input type="hidden" name="myplugin_noncename" id="myplugin_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	?>
		<textarea style="width: 98%;" cols="40" rows="1" name="update_message_text" id="update_message_text"><?php echo get_post_meta($post->ID, 'update_message_text', true); ?></textarea>
		<p>If you have been updated this post / page with new information, use this box to inform about it.</p>
	<?php
}

function update_message_save($post_id)
{
	if ( !wp_verify_nonce( $_POST['myplugin_noncename'], plugin_basename(__FILE__) ))
	{
		return $post_id;
	}

	if ( 'page' == $_POST['post_type'] )
	{
		if ( !current_user_can( 'edit_page', $post_id ))
			return $post_id;
	}
	else
	{
		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
	}
	$mydata = $_POST['update_message_text'];
	update_update_message_meta($post_id, $mydata, 'update_message_text');
}

function update_update_message_meta($post_id, $newvalue, $field_name)
{
	if(!get_post_meta($post_id, $field_name))
		add_post_meta($post_id, $field_name, $newvalue);
	else
		update_post_meta($post_id, $field_name, $newvalue);
}

function get_update_message_box()
{
	global $post;
	$settings = get_option('wpudma');
	$update_message_text = get_post_meta($post->ID, 'update_message_text', true);
	
	$html = stripslashes($settings["html"]);
	$modified = $settings["updated_date_format"];
	$published = $settings["published_date_format"];

	if($html == '')
	{
		$html = '<div class="update_message">
			<small>Updated: %ud%</small>
			<p>%ut%</p>
		</div>';
	}
	
	$html = str_replace('%ud%', get_the_modified_date($modified), $html);
	$html = str_replace('%pd%', get_the_time($published), $html);
	$html = str_replace('%ut%', $update_message_text, $html);
	
	if($update_message_text != '')
		return $html;
	else
		return '';
}

function update_message_box()
{
	echo get_update_message_box();
}

function update_message_content($content)
{
	if(is_single() || is_page())
	{
		$html = get_update_message_box();
		$settings = get_option('wpudma');
		
		$position = $settings['position'];
		$return = $settings['return'];
		
		if($position == '')
			$position = "top";
		
		if($html != '')
		{
			switch ($position)
			{
				case "top":
					$content = $html . $content;
					break;
				case "bottom":
					$content = $content . $html;
					break;
				case "both":
					$content = $html . $content . $html;
					break;
			}
		}
		if($return != '')
		{
			$content = str_replace("\n\r", $return, $content);
		}
		else {
			$content = str_replace("\n\r", '</p><p>', $content);
		}
	}
	
	return $content;
}

function wpudma_options()
{

	if(isset($_POST['save']))
	{
		$settings = array (
			"published_date_format"	=> $_POST["published_date_format"],
			"updated_date_format"	=> $_POST["updated_date_format"],
			"position"				=> $_POST["position"],
			"html"					=> $_POST["html"],
			"return"				=> $_POST["return"],
			"style_theme"			=> $_POST["style_theme"],
		);
		update_option('wpudma', $settings);
		echo "<div id=\"message\" class=\"updated fade\"><p><strong>WP Update Message options updated.</strong></p></div>";
	}
	
	if(isset($_POST['delete']))
	{
		delete_option('wpudma');
	}
	
	$settings = get_option('wpudma');
?>
<div class="wrap">
	<div id="icon-options-general" class="icon32"><br /></div>
		<h2>Update Message Settings</h2>

		<form method="post" target="_self">
			<h3>Date</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row"><label for="published_date_format">Published date <em>format</em></label></th>
					<td>
						<input name="published_date_format" type="text" id="published_date_format" value="<?php echo $settings["published_date_format"]; ?>" class="regular-text code" />
						<span class="setting-description">Default is <code>Wordpress default</code> - <a href="http://php.net/manual/en/function.date.php#function.date.parameters">Parameters</a></span>
					</td>
				</tr>
				
				<tr valign="top">
					<th scope="row"><label for="updated_date_format">Updated date <em>format</em></label></th>
					<td>
						<input name="updated_date_format" type="text" id="updated_date_format" value="<?php echo $settings["updated_date_format"]; ?>" class="regular-text code" />
						<span class="setting-description">Default is <code>Wordpress default</code> - <a href="http://php.net/manual/en/function.date.php#function.date.parameters">Parameters</a></span>
					</td>
				</tr>
			</table>
			
			<h3>Placement</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row"><label for="position">Position</label></th>
					<td>
					<select name="position" id="position" />
						<option value="top"<?php if($settings["position"] == "top" || $settings["position"] == "" || !isset($settings["position"])) { echo ' selected="selected"'; } ?>>Top</option>
						<option value="bottom"<?php if($settings["position"] == "bottom") { echo ' selected="selected"'; } ?>>Bottom</option>
						<option value="both"<?php if($settings["position"] == "both") { echo ' selected="selected"'; } ?>>Both</option>
						<option value="none"<?php if($settings["position"] == "none") { echo ' selected="selected"'; } ?>>None</option>
					</select>
					<span class="setting-description">Default is <code>Top</code></span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="free_position">Free position</label></th>
					<td>
						<span class="setting-description">Call the function <code>&lt?php update_message_box(); ?&gt;</code> somewhere in the loop in your theme.</span>
					</td>
				</tr>
			</table>
			
			<h3>Styles (HTML / CSS)</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row"><label for="html">HTML</label></th>
					<td>
						<textarea name="html" type="text" id="html" value="wp-content/uploads" class="large-text code" rows="4"><?php echo stripslashes($settings["html"]); ?></textarea><br />
						<span class="setting-description"><code>%pd%</code> = Published date</span><br />
						<span class="setting-description"><code>%ud%</code> = Updated date</span><br />
						<span class="setting-description"><code>%ut%</code> = Updated text</span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="default_html">Default HTML</label></th>
					<td>	
						<textarea name="default_html" id="default_html" style="background: #eee" class="large-text code" readonly="readonly" rows="4"><?php
						
						echo "&lt;div class=\"update_message\"&gt;\n";
						echo "&lt;small&gt;Updated: %ud%&lt;/small&gt\n";
						echo "&lt;p&gt;%ut%&lt;/p&gt\n";
						echo "&lt;/div&gt";
						?></textarea>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="return">New row replacement</label></th>
					<td>	
						<input name="return" type="text" id="return" value="<?php echo $settings["return"]; ?>" class="regular-text code" />
						<span class="setting-description">Default is <code>&lt;/p&gt;&lt;p&gt;</code></span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="style_theme">Style theme</label></th>
					<td>	
						<select name="style_theme" id="style_theme" class="style_theme">
							<option value="none"<?php if($settings["style_theme"] == "none") { echo ' selected="selected"'; } ?>>None</option>
							<option value="blue"<?php if($settings["style_theme"] == "blue") { echo ' selected="selected"'; } ?>>Blue</option>
							<option value="dark"<?php if($settings["style_theme"] == "dark") { echo ' selected="selected"'; } ?>>Dark</option>
							<option value="green"<?php if($settings["style_theme"] == "green" || $settings["style_theme"] == "" || !isset($settings["style_theme"])) { echo ' selected="selected"'; } ?>>Green</option>
							<option value="red"<?php if($settings["style_theme"] == "red") { echo ' selected="selected"'; } ?>>Red</option>
							<option value="yellow"<?php if($settings["style_theme"] == "yellow") { echo ' selected="selected"'; } ?>>Yellow</option>
						</select>
						<span class="setting-description">Default is <code>green</code>. The styles are based on the <code>Default HTML</code> settings</span>
					</td>
				</tr>
			</table>
			
			<p class="submit">
				<input type="submit" name="save" class="button-primary" value="Save settings" />
				<input type="submit" name="delete" class="button-primary" value="Delete settings" />
			</p>

		</form>
	</div>
</div>
	<?php
}
?>